OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nie je možné zapisovat do priečinka \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s konfiguráciou.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Alebo, ak preferujete ponechať súbor config.php iba na čítanie, nastavte v ňom parameter \"config_is_read_only\" na true.",
    "See %s" : "Pozri %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Aplikácia %1$s nie je prítomná alebo má nekompatibilnú verziu s týmto serverom. Prosím, skontrolujte adresár aplikácií.",
    "Sample configuration detected" : "Detekovaná bola vzorová konfigurácia",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Zistilo sa, že konfigurácia bola skopírovaná zo vzorových súborov. Takáto konfigurácia nie je podporovaná a môže poškodiť vašu inštaláciu. Prečítajte si dokumentáciu pred vykonaním zmien v config.php",
    "The page could not be found on the server." : "Stránka nebola nájdená na serveri.",
    "%s email verification" : "%s overenie e-mailu",
    "Email verification" : "Overenie e-mailu",
    "Click the following button to confirm your email." : "Kliknite na tlačítko pre potvrdenie vašeho e-mailu.",
    "Click the following link to confirm your email." : "Kliknite na odkaz pre potvrdenie vašeho e-mailu.",
    "Confirm your email" : "Potvrďte svoj e-mail",
    "Other activities" : "Iné aktivity",
    "%1$s and %2$s" : "%1$s a %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s a %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s a %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s a %5$s",
    "Education bundle" : "Sada pre vzdelávanie",
    "Enterprise bundle" : "Enterprise balíček",
    "Groupware bundle" : "Balíček groupware",
    "Hub bundle" : "Sada pre centrum aktivity (hub)",
    "Public sector bundle" : "Balík pre verejný sektor",
    "Social sharing bundle" : "Balíček sociálneho zdieľania",
    "PHP %s or higher is required." : "Požadovaná verzia PHP %s alebo vyššia.",
    "PHP with a version lower than %s is required." : "PHP je vyžadované vo vyššej verzii ako %s.",
    "%sbit or higher PHP required." : "%sbit alebo vyššie PHP je vyžadované.",
    "The following architectures are supported: %s" : "Podporované sú nasledujúce architektúry: %s",
    "The following databases are supported: %s" : "Podporované sú nasledujúce databázy: %s",
    "The command line tool %s could not be found" : "Nástroj príkazového riadka %s nebol nájdený",
    "The library %s is not available." : "Knižnica %s je nedostupná.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Požadovaná je knižnica %1$s vo vyššej verzii ako %2$s - dostupná verzia %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Požadovaná je knižnica %1$s v nižšej verzii ako %2$s - dostupná verzia %3$s.",
    "The following platforms are supported: %s" : "Podporované sú nasledujúce platformy: %s",
    "Server version %s or higher is required." : "Je vyžadovaná verzia servera %s alebo vyššia.",
    "Server version %s or lower is required." : "Je vyžadovaná verzia servera %s alebo nižšia.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Prihlásený účet musí byť správcom, podadministrátorom alebo musí mať špeciálne právo na prístup k tomuto nastaveniu.",
    "Your current IP address doesn’t allow you to perform admin actions" : "Vaša aktuálna adresa IP vám neumožňuje vykonávať akcie správcu",
    "Logged in account must be an admin or sub admin" : "Prihlásený účet musí byť správcom alebo sub správcom.",
    "Logged in account must be an admin" : "Prihlásený účet musí byť správcom",
    "Wiping of device %s has started" : "Začalo sa mazanie zariadenia %s",
    "Wiping of device »%s« has started" : "Začalo sa mazanie zariadenia „%s“",
    "»%s« started remote wipe" : "„%s“ začalo mazanie na diaľku",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Zariadenie alebo aplikácia „%s“ začal proces mazania na diaľku. Po dokončení procesu dostanete ďalší e-mail",
    "Wiping of device %s has finished" : "Mazanie zariadenia %s bolo dokončené.",
    "Wiping of device »%s« has finished" : "Mazanie zariadenia „%s“ bolo dokončené.",
    "»%s« finished remote wipe" : "„%s“ dokončilo mazanie na diaľku ",
    "Device or application »%s« has finished the remote wipe process." : "Zariadenie alebo aplikácia „%s“ dokončilo(a) proces mazania na diaľku.",
    "Remote wipe started" : "Začalo mazanie na diaľku",
    "A remote wipe was started on device %s" : "Na zariadeni %s začalo mazanie na diaľku",
    "Remote wipe finished" : "Mazanie na diaľku bolo dokončené",
    "The remote wipe on %s has finished" : "Mazanie na diaľku na %s bolo dokončené",
    "Authentication" : "Autentifikácia",
    "Unknown filetype" : "Neznámy typ súboru",
    "Invalid image" : "Chybný obrázok",
    "Avatar image is not square" : "Obrázok avatara nie je štvorcový",
    "Files" : "Súbory",
    "View profile" : "Zobraziť profil",
    "Local time: %s" : "Miestny čas: %s",
    "today" : "dnes",
    "tomorrow" : "zajtra",
    "yesterday" : "včera",
    "_in %n day_::_in %n days_" : ["o %n deň","o %n dni","o %n dní","o %n dní"],
    "_%n day ago_::_%n days ago_" : ["včera","pred %n dňami","pred %n dňami","pred %n dňami"],
    "next month" : "budúci mesiac",
    "last month" : "minulý mesiac",
    "_in %n month_::_in %n months_" : ["o %n mesiac ","o %n mesiace","o %n mesiacov","o %n mesiacov"],
    "_%n month ago_::_%n months ago_" : ["pred %n mesiacom","pred %n mesiacmi","pred %n mesiacmi","pred %n mesiacmi"],
    "next year" : "budúci rok",
    "last year" : "minulý rok",
    "_in %n year_::_in %n years_" : ["o %n rok","o %n roky","o %n rokov","o %n rokov"],
    "_%n year ago_::_%n years ago_" : ["vlani","pred %n rokmi","pred %n rokmi","pred %n rokmi"],
    "_in %n hour_::_in %n hours_" : ["o %n hodinu","o %n hodiny","o %n hodín","o %n hodín"],
    "_%n hour ago_::_%n hours ago_" : ["pred %n hodinou","pred %n hodinami","pred %n hodinami","pred %n hodinami"],
    "_in %n minute_::_in %n minutes_" : ["o %n minútu","o %n minúty","o %n minút","o %n minút"],
    "_%n minute ago_::_%n minutes ago_" : ["pred %n minútou","pred %n minútami","pred %n minútami","pred %n minútami"],
    "in a few seconds" : "o pár sekúnd",
    "seconds ago" : "pred sekundami",
    "Empty file" : "Prázdny súbor",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s ID: %s neexistuje. Povoľte ho prosím vo vašom nastavení aplikácií alebo kontaktujte správcu.",
    "Dot files are not allowed" : "Názov súboru začínajúci bodkou nie je povolený.",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" je zakázané pre súbor alebo adresár",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" je zakázaná predpona pre názov súboru alebo adresára.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" nie je povolené v názve súboru alebo adresára",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" nie je povolený typ súboru",
    "Filenames must not end with \"%1$s\"." : "Názvy súborov nemôžu končiť na \"%1$s\".",
    "Invalid parent path" : "Neplatná nadradená cesta",
    "File already exists" : "Súbor už existuje",
    "Invalid path" : "Neplatná cesta",
    "Failed to create file from template" : "Nemôžem vytvoriť súbor zo šablóny",
    "Templates" : "Šablóny",
    "Path contains invalid segments" : "Cesta obsahuje neplatné časti",
    "Filename is a reserved word" : "Názov súboru je rezervované slovo",
    "Filename contains at least one invalid character" : "Názov súboru obsahuje najmenej jeden nepovolený znak",
    "Filename is too long" : "Meno súboru je veľmi dlhé",
    "Empty filename is not allowed" : "Prázdny názov súboru nie je povolený",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikáciu \"%s\" nie je možné nainštalovať, lebo nebolo možné načítať súbor s informáciami o aplikácií.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikácia \"%s\" nie je kompatibilná s verziou servera, preto nemôže byť nainštalovaná.",
    "__language_name__" : "Slovenčina",
    "This is an automatically sent email, please do not reply." : "Toto je automaticky odosielaný e-mail, prosím, neodpovedajte.",
    "Help & privacy" : "Pomoc a ochrana osobých údajov",
    "Appearance and accessibility" : "Vzhľad a správanie",
    "Apps" : "Aplikácie",
    "Personal settings" : "Osobné nastavenia",
    "Administration settings" : "Nastavenia administrácie",
    "Settings" : "Nastavenia",
    "Log out" : "Odhlásiť sa",
    "Accounts" : "Účty",
    "Email" : "E-mail",
    "Mail %s" : "Pošta pre %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Zobraziť %s na fediverse",
    "Phone" : "Telefón",
    "Call %s" : "Zavolať %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Zobraziť %s na Twitteri",
    "Website" : "Webstránka",
    "Visit %s" : "Navštíviť %s",
    "Address" : "Adresa",
    "Profile picture" : "Profilový obrázok",
    "About" : "O aplikácii",
    "Display name" : "Zobrazované meno",
    "Headline" : "Titul",
    "Organisation" : "Organizácia",
    "Role" : "Rola",
    "Pronouns" : "Zámená",
    "Unknown account" : "Neznámy účet",
    "Additional settings" : "Ďalšie nastavenia",
    "Enter the database Login and name for %s" : "Zadajte prihlasovacie meno a názov databázy pre %s",
    "Enter the database Login for %s" : "Zadajte prihlasovacie meno databázy pre %s",
    "Enter the database name for %s" : "Zadajte názov databázy pre %s",
    "You cannot use dots in the database name %s" : "V názve databázy %s nemôžete používať bodky",
    "MySQL Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo do MySQL je neplatné",
    "You need to enter details of an existing account." : "Musíte zadať údaje existujúceho účtu.",
    "Oracle connection could not be established" : "Nie je možné pripojiť sa k Oracle",
    "Oracle Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo pre Oracle databázu je neplatné",
    "PostgreSQL Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo pre PostgreSQL databázu je neplatné",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nie je podporovaný a %s nebude správne fungovať na tejto platforme. Použite ho na vlastné riziko!",
    "For the best results, please consider using a GNU/Linux server instead." : "Pre dosiahnutie najlepších výsledkov, prosím zvážte použitie GNU/Linux servera.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá sa, že táto inštancia %s beží v 32-bitovom prostredí PHP a v php.ini bola nastavená voľba open_basedir. To bude zdrojom problémov so súbormi väčšími ako 4GB a dôrazne sa neodporúča.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Prosím, odstráňte nastavenie open_basedir vo vašom php.ini alebo prejdite na 64-bit PHP.",
    "Set an admin Login." : "Nastaviť prihlasovacie meno administrátora.",
    "Set an admin password." : "Zadajte heslo administrátora.",
    "Cannot create or write into the data directory %s" : "Nemožno vytvoriť alebo zapisovať do priečinka dát %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend pre zdieľanie %s musí implementovať rozhranie OCP\\Share_Backend",
    "Sharing backend %s not found" : "Backend sprístupnenia %s nebol nájdený",
    "Sharing backend for %s not found" : "Backend sprístupnenia pre %s nebol nájdený",
    "%1$s shared %2$s with you" : "%1$s s vami zdieľal %2$s ",
    "Open %s" : "Otvoriť %s",
    "%1$s via %2$s" : "%1$s cez %2$s",
    "Passwords are enforced for link and mail shares" : "Heslo je vyžadováné pre zdieľanie odkazom alebo e-mailom",
    "Share recipient is not a valid user" : "Príjemca zdieľania nie je platným uživateľom",
    "Share recipient is not a valid group" : "Príjemca zdieľania nie je platnou skupinou",
    "Share recipient should be empty" : "Príjemca zdieľania musí byť prázdny",
    "Share recipient should not be empty" : "Príjemca zdieľania nemôže byť prázdny",
    "Share recipient is not a valid circle" : "Príjemca zdieľania nie je platný kruh",
    "Unknown share type" : "Neplatný typ sprístupnenia",
    "Share initiator must be set" : "Musí byť nastavený iniciátor zdieľania",
    "Cannot share with yourself" : "Nie je možné zdieľanie so sebou samým",
    "Shared path must be set" : "Musí byť nastavená zdieľaná cesta",
    "Shared path must be either a file or a folder" : "Zdieľaná cesta musí byť súbor alebo adresár",
    "You cannot share your root folder" : "Nemôžete zdieľať váš koreňový adresár",
    "You are not allowed to share %s" : "Nemôžete sprístupniť %s",
    "Valid permissions are required for sharing" : "Pre zdieľanie sú potrebné korektné práva",
    "Cannot increase permissions of %s" : "Nie je možné navýšiť oprávnenia pre %s",
    "Shares need at least read permissions" : "Zdieľanie vyžaduje minimálne práva na čítanie",
    "Files cannot be shared with delete permissions" : "Súbory nie je možné sprístupňovať s oprávneniami na odstránenie",
    "Files cannot be shared with create permissions" : "Súbory nie je možné sprístupňovať s oprávneniami na vytváranie",
    "Expiration date is in the past" : "Dátum konca platnosti je v minulosti",
    "Expiration date is enforced" : "Dátum expirácie je vyžadovaný",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nie je možné nastaviť dátum konca platnosti viac ako %s deň v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti","Nie je možné nastaviť dátum konca platnosti viac ako %s dní v budúcnosti"],
    "Sharing is only allowed with group members" : "Zdieľanie je možné iba s členmi skupiny",
    "Sharing %s failed, because this item is already shared with the account %s" : "Zdieľanie %s zlyhalo, pretože táto položka už je užívateľovi %s zozdieľaná.",
    "Group sharing is now allowed" : "Zdieľanie pre skupiny je teraz povolené",
    "Sharing is only allowed within your own groups" : "Zdieľanie je povolené len pre vašu vlastnú skupinu",
    "Path is already shared with this group" : "Cesta je už zdieľaná s touto skupinou",
    "Link sharing is not allowed" : "Zdieľanie odkazu nie je povolené",
    "Public upload is not allowed" : "Verejné nahrávanie nie je povolené",
    "Path contains files shared with you" : "Cesta obsahuje súbory zdieľané s vami",
    "Sharing is disabled" : "Zdieľanie je zakázané",
    "Sharing is disabled for you" : "Zdieľanie je pre vás zakázané",
    "Cannot share with the share owner" : "Nie je možné zdieľať s vlastníkom",
    "Share does not have a full ID" : "Zdieľanie nemá plné ID",
    "Cannot change share type" : "Nie je možné zmeniť typ zdieľania",
    "Can only update recipient on user shares" : "Príjemcu je možné aktualizovať iba v užívateľských zdieľaniach",
    "Invalid share recipient" : "Neplatný príjemca zdieľania",
    "Group \"%s\" does not exist" : "Skupina \"%s\" neexistuje",
    "The requested share does not exist anymore" : "Požadované zdieľanie už neexistuje",
    "The requested share comes from a disabled user" : "Požadované zdieľanie pochádza od zakázaného užívateľa.",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Bol dosiahnutý limit používateľov a používateľ nebol vytvorený. Pozrite sa do upozornení pre viac informácií.",
    "Could not find category \"%s\"" : "Nemožno nájsť danú kategóriu \"%s\"",
    "Input text" : "Vstupný text",
    "The input text" : "Vstupný text",
    "Sunday" : "Nedeľa",
    "Monday" : "Pondelok",
    "Tuesday" : "Utorok",
    "Wednesday" : "Streda",
    "Thursday" : "Štvrtok",
    "Friday" : "Piatok",
    "Saturday" : "Sobota",
    "Sun." : "Ned.",
    "Mon." : "Pon.",
    "Tue." : "Uto.",
    "Wed." : "Str.",
    "Thu." : "Štv.",
    "Fri." : "Pia.",
    "Sat." : "Sob.",
    "Su" : "Ne",
    "Mo" : "Po",
    "Tu" : "Ut",
    "We" : "St",
    "Th" : "Št",
    "Fr" : "Pi",
    "Sa" : "So",
    "January" : "Január",
    "February" : "Február",
    "March" : "Marec",
    "April" : "Apríl",
    "May" : "Máj",
    "June" : "Jún",
    "July" : "Júl",
    "August" : "August",
    "September" : "September",
    "October" : "Október",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Máj.",
    "Jun." : "Jún.",
    "Jul." : "Júl.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "Musíte zadať platné heslo",
    "The Login is already being used" : "Prihlasovacie meno sa už používa",
    "Could not create account" : "Nepodarilo sa vytvoriť účet",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "V prihlasovacom mene je možné použiť iba nasledovné znaky: \"a-z\", \"A-Z\", \"0-9\", medzery a \"_.@-'\"",
    "A valid Login must be provided" : "Musíte zadať platné prihlasovacie meno.",
    "Login contains whitespace at the beginning or at the end" : "Prihlasovacie meno obsahuje medzeru na začiatku alebo na konci.",
    "Login must not consist of dots only" : "Prihlasovacie meno sa nesmie skladať len z bodiek",
    "Login is invalid because files already exist for this user" : "Prihlasovacie meno je neplatné, pretože pre tohto užívateľa už existujú súbory.",
    "Account disabled" : "Účet bol zakázaný",
    "Login canceled by app" : "Prihlásenie bolo zrušené aplikáciou",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikáciu \"%1$s\" nie je možné inštalovať, pretože nie sú splnené nasledovné závislosti: %2$s",
    "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
    "Application is not enabled" : "Aplikácia nie je zapnutá",
    "Authentication error" : "Chyba autentifikácie",
    "Token expired. Please reload page." : "Token vypršal. Obnovte, prosím, stránku.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ovládače databázy (sqlite, mysql, alebo postgresql) nie sú nainštalované.",
    "Cannot write into \"config\" directory." : "Nie je možné zapisovať do priečinka \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do adresára s konfiguráciou. Viď %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Alebo, ak preferujete ponechať súbor config.php iba na čítanie, nastavte v ňom parameter \"config_is_read_only\" na true.  Viď %s",
    "Cannot write into \"apps\" directory." : "Nie je možné zapisovať do priečinka \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s aplikáciami alebo vypnutím katalógu s aplikáciami v súbore s nastaveniami.",
    "Cannot create \"data\" directory." : "Nie je možné vytvoriť priečinok \"data\"",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového adresára. Viď %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Oprávnenia je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového priečinka. Viď %s.",
    "Your data directory is not writable." : "Priečinok s dátami nie je zapisovateľný.",
    "Setting locale to %s failed." : "Nastavenie locale na %s zlyhalo.",
    "Please install one of these locales on your system and restart your web server." : "Prosím, nainštalujte si aspoň jeden z týchto jazykov do svojho systému a reštartujte webserver.",
    "PHP module %s not installed." : "PHP modul %s nie je nainštalovaný.",
    "Please ask your server administrator to install the module." : "Prosím, požiadajte administrátora vášho servera o inštaláciu modulu.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Voľba PHP „%s“ nie je nastavená na „%s“.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Použitím týchto nastavení v php.ini dovolí Nextcloudu sa znova spustiť",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> je nastavený na <code>%s</code>, namiesto predpokladanej hodnoty <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Oprava problému spočíva v nastavení <code>mbstring.func_overload</code> na <code>0</code> vo vašom php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je zjavne nastavené, aby odstraňovalo bloky vloženej dokumentácie. To zneprístupní niekoľko základných aplikácií.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "To je pravdepodobne spôsobené cache/akcelerátorom ako napr. Zend OPcache alebo eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly boli nainštalované, ale stále sa tvária, že chýbajú?",
    "Please ask your server administrator to restart the web server." : "Prosím, požiadajte administrátora vášho servera o reštartovanie webového servera.",
    "The required %s config variable is not configured in the config.php file." : "Požadovaná konfiguračná premenná %s nie je nakonfigurovaná v súbore config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Požiadajte správcu servera, aby skontroloval konfiguráciu Nextcloud.",
    "Your data directory is readable by other people." : "Váš adresár s dátami je prístupný na čítanie ostatným ľuďom.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Prosím, zmeňte oprávnenia na 0770, aby tento adresár nemohli ostatní ľudia otvoriť.",
    "Your data directory must be an absolute path." : "Priečinok s dátami musí byť zadaný ako absolútna cesta.",
    "Check the value of \"datadirectory\" in your configuration." : "Skontrolujte hodnotu \"datadirectory\" vo vašej konfigurácii.",
    "Your data directory is invalid." : "Priečinok pre dáta je neplatný.",
    "Action \"%s\" not supported or implemented." : "Akcia \"%s\" nie je podporovaná alebo implementovaná.",
    "Authentication failed, wrong token or provider ID given" : "Autentifikácia zlyhala, bol zadaný neplatný token alebo ID poskytovateľa",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Pre dokončenie požiadavky chýbajú parametre.  Chýbajúce parametre: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" je už použité v združenom cloude \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Poskytovateľ združeného cloudu s ID: \"%s\" neexistuje.",
    "Could not obtain lock type %d on \"%s\"." : "Nepodarilo sa získať zámok typu %d na „%s“.",
    "Storage unauthorized. %s" : "Úložisko neoverené. %s",
    "Storage incomplete configuration. %s" : "Neplatná konfigurácia úložiska. %s",
    "Storage connection error. %s" : "Chyba pripojenia k úložisku. %s",
    "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
    "Storage connection timeout. %s" : "Vypršanie pripojenia k úložisku. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Ak chcete povoliť spustenie tejto kontroly, musíte sa uistiť, že váš webový server sa môže pripojiť sám k sebe. Preto musí byť schopný rozpoznať a pripojiť sa aspoň k jednej zo svojich `trusted_domains` alebo `overwrite.cli.url`.  Výsledkom nesprávneho nastavenia môže byť nesúlad DNS na strane servera alebo pravidla brány firewall pre výstup.",
    "Transcribe audio" : "Prepísať zvuk",
    "Transcribe the things said in an audio" : "Prepísať veci povedané vo zvuku",
    "Audio input" : "Audio vstup",
    "The audio to transcribe" : "Zvuk pre prepísanie",
    "Transcription" : "Prepis",
    "The transcribed text" : "Prepísaný text",
    "Chat message" : "Správa chatu",
    "Confirmation" : "Potvrdenie",
    "Context write" : "Kontextový zápis",
    "Writes text in a given style based on the provided source material." : "Napíše text v danom štýle na základe poskytnutého zdrojového materiálu.",
    "Writing style" : "Štýl písania",
    "Demonstrate a writing style that you would like to immitate" : "Ukážte štýl písania, ktorý by ste chceli napodobniť",
    "Source material" : "Zdrojový materiál",
    "The content that would like to be rewritten in the new writing style" : "Obsah, ktorý by bol prepísaný do nového štýlu písania",
    "Generated text" : "Vygenerovaný text",
    "The generated text with content from the source material in the given style" : "Vygenerovaný text s obsahom zo zdrojového materiálu v danom štýle",
    "Emoji generator" : "Generátor emotikonov",
    "Takes text and generates a representative emoji for it." : "Zoberie text a vygeneruje pre neho reprezentatívny emotikon.",
    "The text to generate an emoji for" : "Text pre ktorý vygeneruje emotikon",
    "Generated emoji" : "Vygenerované emotikony",
    "The generated emoji based on the input text" : "Vygenerovaný emotikon založený na vstupnom texte",
    "Generate image" : "Vygenerovať obrázok",
    "Generate an image from a text prompt" : "Vygenerovať obrázok na základe textového zadania",
    "Prompt" : "Zadanie",
    "Describe the image you want to generate" : "Popíšte obrázok ktorý chcete vygenerovať",
    "Number of images" : "Počet obrázkov",
    "How many images to generate" : "Koľko obrázkov sa bude generovať",
    "Output images" : "Výstupné obrázky",
    "The generated images" : "Vygenerované obrázky",
    "Generated reply" : "Vygenerovaná odpoveď",
    "Chat" : "Chat",
    "Chat with the assistant" : "Chat s asistentom",
    "System prompt" : "Systémová výzva",
    "Chat history" : "História chatu",
    "Response message" : "Správa s odpoveďou",
    "Tool message" : "Správa nástroja",
    "Available tools" : "Dostupné nástroje",
    "Formalize text" : "Formalizovať text",
    "Formalized text" : "Formalizovaný text",
    "The formalized text" : "Formalizovaný text",
    "Generate a headline" : "Vygenerovať titulok",
    "Generates a possible headline for a text." : "Generuje možný nadpis pre text.",
    "Original text" : "Originálny text",
    "The original text to generate a headline for" : "Originálny text pre ktorý sa vygeneruje titulok",
    "The generated headline" : "Vygenerovaný titulok",
    "Text" : "Text",
    "Corrections" : "Opravy",
    "Reformulate text" : "Preformulovať text",
    "Takes a text and reformulates it" : "Zoberie text a preformuluje ho",
    "Write a text that you want the assistant to reformulate" : "Napíšte text pre ktorý chcete aby asistent preforumuloval",
    "Reformulated text" : "Preformulovaný text",
    "The reformulated text, written by the assistant" : "Preformulovaný text, ktorý napísal asistent",
    "Simplify text" : "Zjednodušiť text",
    "Takes a text and simplifies it" : "Zobrať text a zjednodušiť ho",
    "Write a text that you want the assistant to simplify" : "Napíšte text ktorý chcete od asistenta zjednodušiť",
    "Simplified text" : "Zjednodušený text",
    "The simplified text" : "Zjednodušený text",
    "Summarize" : "Zhrnutie",
    "Summarizes a text" : "Zhrnutie textu",
    "The original text to summarize" : "Originálny text pre zhrnutie",
    "Summary" : "Súhrn",
    "The generated summary" : "Vygenerované zhrnutie",
    "Extract topics" : "Extrahovať témy",
    "Extracts topics from a text and outputs them separated by commas" : "Vyextrahovať témy z textu a vypísať ich ako zoznam oddelený čiarkami",
    "The original text to extract topics from" : "Originálny text z ktorého sa vyextrahujú témy",
    "Topics" : "Témy",
    "The list of extracted topics" : "Zoznam vyextrahovaných tém",
    "Translate" : "Preložiť",
    "Translate text from one language to another" : "Preložiť text z jedného jazyka do druhého",
    "Origin text" : "Pôvodný text",
    "The text to translate" : "Text pre preklad",
    "Origin language" : "Pôvodný jazyk",
    "The language of the origin text" : "Jazyk pôvodného textu",
    "Target language" : "Cieľový jazyk",
    "The desired language to translate the origin text in" : "Požadovaný jazyk, do ktorého sa má preložiť pôvodný text",
    "Result" : "Výsledok",
    "The translated text" : "Preložený text",
    "Free prompt" : "Bezplatný formulár",
    "Runs an arbitrary prompt through the language model." : "Spúšťa ľubovoľný príkaz cez jazykový model.",
    "Generate headline" : "Generovať nadpis",
    "Summarizes text by reducing its length without losing key information." : "Zhrňuje text tým, že znižuje jeho dĺžku bez straty kľúčových informácií.",
    "Extracts topics from a text and outputs them separated by commas." : "Extrahuje témy z textu a vypisuje ich oddelené čiarkami.",
    "Education Edition" : "Edícia pre výuku",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prihlásený používateľ musí byť správcom, podadministrátorom alebo musí mať špeciálne právo na prístup k tomuto nastaveniu",
    "Logged in user must be an admin or sub admin" : "Prihlásený používateľ musí byť správcom alebo správcom pre čiastkovú oblasť.",
    "Logged in user must be an admin" : "Prihlásený používateľ musí byť správca",
    "File name is a reserved word" : "Názov súboru je rezervované slovo.",
    "File name contains at least one invalid character" : "Názov súboru obsahuje nepovolené znaky.",
    "File name is too long" : "Meno súboru je veľmi dlhé.",
    "Help" : "Pomoc",
    "Users" : "Používatelia",
    "Unknown user" : "Neznámy používateľ",
    "Enter the database username and name for %s" : "Zadajte užívateľské meno a názov databázy pre %s",
    "Enter the database username for %s" : "Zadajte užívateľské meno databázy pre %s",
    "MySQL username and/or password not valid" : "Neplatné užívateľské meno a/alebo heslo do MySQL",
    "Oracle username and/or password not valid" : "Používateľské meno a/alebo heslo pre Oracle databázu je neplatné",
    "PostgreSQL username and/or password not valid" : "Používateľské meno a/alebo heslo pre PostgreSQL databázu je neplatné",
    "Set an admin username." : "Zadajte používateľské meno administrátora.",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s vám sprístupnil »%2$s« s poznámkou:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s vám sprístupnil »%2$s« s poznámkou",
    "»%s« added a note to a file shared with you" : "»%s« pridal poznámku k súboru ktorý s Vami zdieľa",
    "Open »%s«" : "Otvoriť »%s«",
    "Sharing %s failed, because this item is already shared with user %s" : "Zdieľanie %s zlyhalo, táto položka už je používateľovi %s zozdieľaná",
    "%1$s shared »%2$s« with you" : "%1$s vám sprístupnil »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s vám sprístupnil »%2$s«.",
    "Click the button below to open it." : "Pre otvorenie klienta kliknite na tlačítko nižšie.",
    "The username is already being used" : "Meno používateľa je už použité",
    "Could not create user" : "Nepodarilo sa vytvoriť používateľa",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "V mene užívateľa je možné použiť iba nasledovné znaky: \"a-z\", \"A-Z\", \"0-9\", medzery a \"_.@-'\"",
    "A valid username must be provided" : "Musíte zadať platné používateľské meno",
    "Username contains whitespace at the beginning or at the end" : "Meno používateľa obsahuje na začiatku, alebo na konci medzeru",
    "Username must not consist of dots only" : "Používateľské meno sa nesmie skladať len z bodiek",
    "Username is invalid because files already exist for this user" : "Používateľské meno je neplatné, pretože pre tohto používateľa už existujú súbory",
    "User disabled" : "Používateľ zakázaný",
    "File is currently busy, please try again later" : "Súbor sa práve používa, skúste prosím neskôr",
    "Cannot download file" : "Nemožno stiahnuť súbor",
    "Your data directory is readable by other users." : "Váš priečinok s dátami je prístupný na čítanie ostatným užívateľom.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Prosím, zmeňte oprávnenia na 0770, aby tento priečinok nemohli ostatní používatelia otvoriť.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Uistite sa, že v koreňovom adresári sa nachádza súbor s názvom \".ocdata\"."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
